//-------------------------------------------------------------------------
//
//   Project:          		JScript
//   (c) copyright     	Andreas Weschenfelder
//-------------------------------------------------------------------------






//------------------------------------------------------------------------
// Global Variables
//------------------------------------------------------------------------
var FT2232BSC  = new ActiveXObject("FT2232_BoundaryScan.coFT2232BoundaryScan");
var current_path = fileGetCurDir() + "/";
var BSDL_FileName = current_path + "../bsdl_files/FHE_XA3S500E_FT256.bsdl";


//________________________________________________________________________
//\  \     \  \     \  \     \  \     \  \     \  \     \  \
// \  \     \  \     \  \     \  \     \  \     \  \     \  \
//  \  \     \  \     \  \     \  \     \  \     \  \     \  \
//   \  \     \  \     \  \     \  \     \  \     \  \     \  \
//
//   S C R I P T   S T A R T
//________________________________________________________________________


Write(" ");
Write("--------------------------------------------");
Write(">>> Script is initializing... ");
Write("--------------------------------------------");
var main_ret = main();
Write("--------------------------------------------");
Write(">>> Script finished... return code: " + main_ret );
Write("--------------------------------------------");

//________________________________________________________________________
//
//   S C R I P T    E N D
//
//   /  /     /  /     /  /     /  /     /  /     /  /     /  /
//  /  /     /  /     /  /     /  /     /  /     /  /     /  /
// /  /     /  /     /  /     /  /     /  /     /  /     /  /
//________________________________________________________________________


//------------------------------------------------------------------------
// Functions
//------------------------------------------------------------------------

//---------------------------------------------------------------------
// function: include()
//
// input:    filename to include to script
// output:   String containing complete file content
// comment:
//----------------------------------------------------------------------
function Include(jsFile) {
   WScript.StdOut.WriteLine("#include "+jsFile+" ...");
   fso = new ActiveXObject("Scripting.FileSystemObject");
   f = fso.OpenTextFile(jsFile);
   s = f.ReadAll();
   f.Close();
   return s;
}


//---------------------------------------------------------------------
// function: main()
//
// input:    none
// output:   none
// comment:  main routine of the script
//----------------------------------------------------------------------
function main()
{
		
	Write("*************************************************" );
	Write("*                                               *" );
	Write("* BoundaryScan with FT2232                      *" );
	Write("* (c) Andreas Weschenfelder                     *" );
	Write("*                                               *" );
	Write("*************************************************" );


	var i=0;
	var help_string="";
	var help_index;

	var LED0_index,LED1_index,LED2_index,LED3_index,LED4_index,LED5_index;
	var S0_index,S1_index,S2_index,S3_index,S4_index,S5_index,S6_index,S7_index;
	var sw_val;
	
	var jtag_dongles = FT2232BSC.JTAG_ScanDongles();
	
//--------------------------------------------------------------------------------
// Find JTAG dongles
//--------------------------------------------------------------------------------
	if ( jtag_dongles == 0 )
	{
		Write("No JTAG dongle found.");
		return -1;
	} else
	if ( jtag_dongles > 1 )
	{
		Write("Several JTAG dongles found...");
		Write("Please connect only one JTAG dongle.");
		//return -2;
	} else
	{
	Write("-> JTAG dongle found.");
	}
	
//--------------------------------------------------------------------------------
// Lade BSDL file + BSDL-Information...
//--------------------------------------------------------------------------------
	Write("Load BSDL File: " + BSDL_FileName);
	FT2232BSC.BSDL_Filename = BSDL_FileName;
	Write("BS instruction count: " + FT2232BSC.IR_OpCodeCount);
		for (i=0;i<FT2232BSC.IR_OpCodeCount;i++)
		{
			Write( i +". instruction: " + FT2232BSC.IR_Name(i));
		}
	Write("BSR cell count: " + FT2232BSC.BSR_Len);
		for (i=0;i<FT2232BSC.BSR_Len;i++)
		{
			help_string="";
			
			help_string= help_string + "  Num " + FT2232BSC.BSDL_CellNum(i);
			help_string= help_string + "  Type " + FT2232BSC.BSDL_CellType(i);
			help_string= help_string + "  Port " + FT2232BSC.BSDL_CellPort(i);
			help_string= help_string + "  Func " + FT2232BSC.BSDL_CellFunction(i);
			help_string= help_string + "  Dir " + FT2232BSC.BSDL_CellDirection(i);
			help_string= help_string + "  Val " + FT2232BSC.BSDL_CellValue(i);

			Write( i + help_string );
		}
		
//--------------------------------------------------------------------------------
// Connect BSDL-Information with Signals
//--------------------------------------------------------------------------------
		
//Switch
	S0_index = FT2232BSC.BSDL_CellIndexFromPort("IPAD3");		
	S1_index = FT2232BSC.BSDL_CellIndexFromPort("IPAD35");
	S2_index = FT2232BSC.BSDL_CellIndexFromPort("IPAD36");
	S3_index = FT2232BSC.BSDL_CellIndexFromPort("IPAD54");
	S4_index = FT2232BSC.BSDL_CellIndexFromPort("IPAD58");
	S5_index = FT2232BSC.BSDL_CellIndexFromPort("IPAD10");
	S6_index = FT2232BSC.BSDL_CellIndexFromPort("IPAD55");
	S7_index = FT2232BSC.BSDL_CellIndexFromPort("IPAD9");

	
// LEDs
	LED0_index  = FT2232BSC.BSDL_CellIndexFromPort("L12");		
	LED1_index  = FT2232BSC.BSDL_CellIndexFromPort("L13");	
	LED2_index  = FT2232BSC.BSDL_CellIndexFromPort("K14");	
	LED3_index  = FT2232BSC.BSDL_CellIndexFromPort("L15");	
	LED4_index  = FT2232BSC.BSDL_CellIndexFromPort("M16");	
	LED5_index  = FT2232BSC.BSDL_CellIndexFromPort("L14");	
	
	
	if 	(
			(LED0_index == -1) || (LED1_index == -1)||(LED2_index == -1) || (LED3_index == -1) ||  
			(LED4_index == -1) || (LED5_index == -1)||
			(S0_index == -1) || (S1_index == -1)||(S2_index == -1) || (S3_index == -1) ||  
			(S4_index == -1) || (S5_index == -1)||(S6_index == -1) || (S7_index == -1) 
		) 
	{
		Write("BSR: not all cells could be found! Extest LED/Switch will be stopped!" );
		return -3;
	}
	
	

	// Init Part
	FT2232BSC.JTAG_OpenDongle();
	
	if ( FT2232BSC.JTAG_Connected )
	{
	// get IDCode and select the used jtag core
		if (FT2232BSC.JTAG_ChainCount==0)
		{
			Write("No JTAG device found!" );
			FT2232BSC.JTAG_CloseDongle();
			return -4;
		}
		Write("JTAG device chain count: " + FT2232BSC.JTAG_ChainCount );
		for (i=0;i<FT2232BSC.JTAG_ChainCount;i++)
		{
			Write("  "+i+". device: 0x" + FT2232BSC.JTAG_IDCode(i) );
		}
		Write("  " );
		FT2232BSC.JTAG_SelectChainPosition = 0;
		
	
	
	// Init Sequenez (min. 2 mal)
		FT2232BSC.BSDL_Sample();		// Muss VOR dem ersten EXTEST Kommand stehen; ansonsten sind die Werte
		FT2232BSC.BSDL_Sample();		// im BSR Register nicht definiert!
		FT2232BSC.BSDL_Sample();		// Mittels Sample-Abfrage werden dann die gerade aktiven Werte bernommen...	

	//LED 0..7 as output
		FT2232BSC.BSDL_CellValueWrite( LED0_index-1, 0 ); 			//Output 
		FT2232BSC.BSDL_CellValueWrite( LED1_index-1, 0 ); 			//Output 
		FT2232BSC.BSDL_CellValueWrite( LED2_index-1, 0 ); 			//Output 
		FT2232BSC.BSDL_CellValueWrite( LED3_index-1, 0 ); 			//Output 
		FT2232BSC.BSDL_CellValueWrite( LED4_index-1, 0 ); 			//Output 
		FT2232BSC.BSDL_CellValueWrite( LED5_index-1, 0 ); 			//Output 
	// Value
		FT2232BSC.BSDL_CellValueWrite( LED0_index, 0x01 );
		FT2232BSC.BSDL_CellValueWrite( LED1_index, 0x01 );
		FT2232BSC.BSDL_CellValueWrite( LED2_index, 0x01 );
		FT2232BSC.BSDL_CellValueWrite( LED3_index, 0x01 );
		FT2232BSC.BSDL_CellValueWrite( LED4_index, 0x01 );
		FT2232BSC.BSDL_CellValueWrite( LED5_index, 0x01 );

		
		FT2232BSC.WriteOnly = false;
		FT2232BSC.BSDL_Extest();
		
		//Switch Value?
		sw_val = 0;
		sw_val = sw_val + ( FT2232BSC.BSDL_ArrayBitValue_Read(S0_index) << 0 );
		sw_val = sw_val + ( FT2232BSC.BSDL_ArrayBitValue_Read(S1_index) << 1 );
		sw_val = sw_val + ( FT2232BSC.BSDL_ArrayBitValue_Read(S2_index) << 2 );
		sw_val = sw_val + ( FT2232BSC.BSDL_ArrayBitValue_Read(S3_index) << 3 );
		sw_val = sw_val + ( FT2232BSC.BSDL_ArrayBitValue_Read(S4_index) << 4 );
		sw_val = sw_val + ( FT2232BSC.BSDL_ArrayBitValue_Read(S5_index) << 5 );
		sw_val = sw_val + ( FT2232BSC.BSDL_ArrayBitValue_Read(S6_index) << 6 );
		sw_val = sw_val + ( FT2232BSC.BSDL_ArrayBitValue_Read(S7_index) << 7 );
		Write("Switch: " + sw_val );
	
		FT2232BSC.WriteOnly = true;

		for (i=0;i<0x256;i++)
		{
			FT2232BSC.BSDL_ArrayBitValue_Write( LED0_index, ((i>>0) & 0x01) );
			FT2232BSC.BSDL_ArrayBitValue_Write( LED1_index, ((i>>1) & 0x01) );
			FT2232BSC.BSDL_ArrayBitValue_Write( LED2_index, ((i>>2) & 0x01) );
			FT2232BSC.BSDL_ArrayBitValue_Write( LED3_index, ((i>>3) & 0x01) );
			FT2232BSC.BSDL_ArrayBitValue_Write( LED4_index, ((i>>4) & 0x01) );
			FT2232BSC.BSDL_ArrayBitValue_Write( LED5_index, ((i>>5) & 0x01) );

			FT2232BSC.BSDL_ShiftCurData();		// Vorher muss min. einmal Extest aufgerufen sein worden!

			//WScript.sleep(1000);
			
		}

	}
	
	FT2232BSC.JTAG_CloseDongle();
		
	
	WScript.sleep(10);
	Write("END OF MAIN");

return 0;
}





























function fileGetCurDir()
       {
   var fso = new ActiveXObject("Scripting.FileSystemObject");
   return (fso.GetFolder("."));
       }
	   
//---------------------------------------------------------------------
// function: Write()
//
// input:    value:	String to print at the console
// output:   none
//----------------------------------------------------------------------
function Write(value)
{
   WScript.StdOut.WriteLine(value);
}



